# -*- coding: utf-8 -*-
# Generated by Django 1.11.16 on 2019-01-11 07:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pymess', '0003_dialer'),
    ]

    operations = [
        migrations.AddField(
            model_name='dialermessage',
            name='is_final_state',
            field=models.BooleanField(default=False, verbose_name='is done'),
        ),
    ]
